@@ -320,6 +320,17 @@ get_interface_type(int c, int *type_r, gnc_t gnc, void *closure)
     return c;
 }
 
+static void
+free_filter(struct filter *f)
+{
+    free(f->ifname);
+    free(f->id);
+    free(f->prefix);
+    free(f->src_prefix);
+    free(f->neigh);
+    free(f->action.src_prefix);
+    free(f);
+}
 
 static int
 parse_filter(int c, gnc_t gnc, void *closure, struct filter **filter_return)
@@ -341,7 +352,7 @@ parse_filter(int c, gnc_t gnc, void *closure, struct filter **filter_return)
         }
         c = getword(c, &token, gnc, closure);
         if(c < -1) {
-            free(filter);
+            free_filter(filter);
             return -2;
         }
 
@@ -451,8 +462,6 @@ parse_filter(int c, gnc_t gnc, void *closure, struct filter **filter_return)
                 filter->af = af;
             else if(filter->af != af)
                 goto error;
-            if(af == AF_INET && filter->action.src_plen == 96)
-                memset(&filter->action.src_prefix, 0, 16);
         } else if(strcmp(token, "table") == 0) {
             int table;
             c = getint(c, &table, gnc, closure);
@@ -470,15 +479,21 @@ parse_filter(int c, gnc_t gnc, void *closure, struct filter **filter_return)
            filter->src_plen_le < 128 || filter->src_plen_ge > 0)
             filter->af = AF_INET6;
     } else if(filter->af == AF_INET) {
-        filter->plen_le += 96;
-        filter->plen_ge += 96;
+        if(filter->plen_le < 128)
+            filter->plen_le += 96;
+        if(filter->plen_ge > 0)
+            filter->plen_ge += 96;
+        if(filter->src_plen_le < 128)
+            filter->src_plen_le += 96;
+        if(filter->src_plen_ge > 0)
+            filter->src_plen_ge += 96;
     }
     *filter_return = filter;
     return c;
 
  error:
     free(token);
-    free(filter);
+    free_filter(filter);
     return -2;
 }
 
@@ -619,6 +634,8 @@ parse_anonymous_ifconf(int c, gnc_t gnc, void *closure,
     return c;
 
  error:
+    if(if_conf->ifname)
+        free(if_conf->ifname);
     free(if_conf);
     return -2;
 }
@@ -711,6 +728,7 @@ add_ifconf(struct interface_conf *if_conf, struct interface_conf **if_confs)
         while(next) {
             if(strcmp(next->ifname, if_conf->ifname) == 0) {
                 merge_ifconf(next, if_conf, next);
+                free(if_conf->ifname);
                 free(if_conf);
                 if_conf = next;
                 goto done;
@@ -732,6 +750,7 @@ flush_ifconf(struct interface_conf *if_conf)
 {
     if(if_conf == interface_confs) {
         interface_confs = if_conf->next;
+        free(if_conf->ifname);
         free(if_conf);
         return;
     } else {
@@ -739,6 +758,7 @@ flush_ifconf(struct interface_conf *if_conf)
         while(prev) {
             if(prev->next == if_conf) {
                 prev->next = if_conf->next;
+                free(if_conf->ifname);
                 free(if_conf);
                 return;
             }
@@ -755,8 +775,7 @@ parse_option(int c, gnc_t gnc, void *closure, char *token)
        because they require no special setup or because there is special
        case code for them. */
     if(config_finalised) {
-        if(strcmp(token, "keep-unfeasible") != 0 &&
-           strcmp(token, "link-detect") != 0 &&
+        if(strcmp(token, "link-detect") != 0 &&
            strcmp(token, "log-file") != 0 &&
            strcmp(token, "diversity") != 0 &&
            strcmp(token, "diversity-factor") != 0 &&
@@ -798,8 +817,7 @@ parse_option(int c, gnc_t gnc, void *closure, char *token)
             add_import_table(v);
         else
             abort();
-    } else if(strcmp(token, "keep-unfeasible") == 0 ||
-              strcmp(token, "link-detect") == 0 ||
+    } else if(strcmp(token, "link-detect") == 0 ||
               strcmp(token, "random-id") == 0 ||
               strcmp(token, "daemonise") == 0 ||
               strcmp(token, "skip-kernel-setup") == 0 ||
@@ -810,9 +828,7 @@ parse_option(int c, gnc_t gnc, void *closure, char *token)
         if(c < -1)
             goto error;
         b = (b == CONFIG_YES);
-        if(strcmp(token, "keep-unfeasible") == 0)
-            keep_unfeasible = b;
-        else if(strcmp(token, "link-detect") == 0)
+        if(strcmp(token, "link-detect") == 0)
             link_detect = b;
         else if(strcmp(token, "random-id") == 0)
             random_id = b;
