@@ -353,7 +353,6 @@ interface_up(struct interface *ifp, int up)
                 }
             }
         }
-        printf("Type: %d\n", type);
 
         /* Type is CONFIG_TYPE_AUTO if interface is not known to be
            wireless, so provide sane defaults for that case. */
@@ -468,7 +467,6 @@ interface_up(struct interface *ifp, int up)
         send_hello(ifp);
         if(rc > 0)
             send_update(ifp, 0, NULL, 0, NULL, 0);
-        send_request(ifp, NULL, 0, NULL, 0);
     } else {
         flush_interface_routes(ifp, 0);
         ifp->buffered = 0;
@@ -555,7 +553,6 @@ check_interfaces(void)
             check_interface_channel(ifp);
             rc = check_interface_ipv4(ifp);
             if(rc > 0) {
-                send_request(ifp, NULL, 0, NULL, 0);
                 send_update(ifp, 0, NULL, 0, NULL, 0);
             }
         }
